@@ -6,6 +6,7 @@ package Sim::OPT::Interlinear;
 # GPL License 3.0 or newer.
 # This is a program for filling a design space multivariate discrete dataseries
 # through a strategy entailing distance-weighting the nearest-neihbouring gradients.
+
 use v5.14;
 use Math::Round;
 use List::Util qw( min max reduce shuffle any );
@@ -27,17 +28,20 @@ use Sim::OPT::Report;
 use Sim::OPT::Descend;
 use Sim::OPT::Takechance;
 use Sim::OPT::Parcoord3d;
+# NOTE THAT TO USE THE PROGRAM AS A SCRIPT, THE ABOVE "use Sim::OPT..." lines should be deleted.
 
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
-$VERSION = '0.111';
+$VERSION = '0.113';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
 # Interlinear
 #######################################################################
 
+########## AN EXAMPLE OF SETTINGS TO BE PUT IN A CONFIGURATION FILE FOLLOWS.
+
 $tee = new IO::Tee(\*STDOUT, ">>$report"); # GLOBAL ZZZ
 my $maxloops= 1000;
 my $sourcefile = "./minitintcleaned.csv";
@@ -79,7 +83,7 @@ my $limit_checkdistpoints = ""; # LIMIT OF RELATIONS TAKEN INTO ACCOUNT IN CALCU
 my $fulldo = "no"; # TO SEARCH FOR MAXIMUM PRECISION AT THE EXPENSES OF SPEED. "yes" MAKES THE GRADIENTS BE RECALCULATED AT EACH COMPUTATION CYCLE.
 my $lvconversion = ""; # IF "EQUAL", A FRACTION OF LEVEL HAS THE VALUE OF 1, WHATEVER THE NUMBER OF A FRATION OF LEVEL IN A FACTOR. OTHERWISE, A NUMBER.
 
-#######################################################################
+############# END OF THE EXAMPLE SETTINGS TO BE PUT IN A CONFIGURATION FILE.
 
 
 sub odd
@@ -2035,27 +2039,27 @@ Sim::OPT::Interlinear
 
 
 Interlinear is a program for computing the missing values in multivariate datasieries through a strategy entailing distance-weighting the nearest-neihbouring gradients between points in an n-dimensional space.
-The program can adopts a distance-weighted gradient-based strategy. The strategy weights the known gradients in a manner inversely proportional to the distance of their pivot points from the pivot points of the missing nearest-neighbouring gradients, then utilizes recursively the gradients neighbouring near each unknown point to define it, weighting the candidates by distance. In this strategy, the curvatures in the space derive from the fact that in this calculation a local sample of the near-neighbouring gradients is used, which vary for each point. The strategy in question is adopted in Interlinear since version 0.103. Before that version, the gradients were calculated on a global basis.
-Besides the described strategy, a), the following metamodelling strategies are utilized by Interlinear:
+The program adopts a distance-weighted gradient-based strategy. In this strategy, the known gradients are weighted in a manner inversely proportional to the distance of their pivot point from the pivot point of each unknown nearest-neighbouring gradient, then the gradients neighbouring near each unknown point are utilized to define that point, weighting the candidates by distance. In this strategy, the curvatures in the hyperspace derive from the fact that in the calculations local samples of the near-neighbouring gradients are used, which vary for each point. (This strategy is adopted in Interlinear since version 0.103. Before that version, the gradients were calculated on a global basis.)
+Besides the described strategy (a), the following metamodelling strategies are utilized by Interlinear:
 
-b) pure linear interpolation (one may want to use this in some occasions: for example, on factorials);
+b) pure linear interpolation (one may want to use this in some occasions: for example with factorials);
 
 c) pure nearest neighbour (a strategy of last resort. One may want to use it to unlock a computation which is based on data which are too sparse to proceed, or when nothing else works).
 
-Strategy a) works for cases which are adjacent in the design space. For example, it cannot work with the gradient between a certain iteration 1 and the corresponding iteration 3. It can only work with the gradient between iterations 1 and 2, or 2 and 3.
-For that reason, it does not work well with data evenly distributed in the design space, like those deriving from latin hypercube sampling, or a random sampling; and works well with data clustered in small patches, like those deriving from star (coordinate descent) sampling strategies.
+Strategy a) in the adopted setting, works with cases which are adjacent in the design space. In that setting, it the strategy cannot work with the gradient between a certain iteration 1 and the corresponding iteration 3. It can only work with the gradient between iterations 1 and 2, or 2 and 3. (This is a design decision, but it is not inevitable. Versions of Interlinear prior to 0.103 could work with non-adiacent instances, if wanted.)
+For the told reason, Interlinear does not work well with data evenly distributed in the design space, like those deriving from latin hypercube sampling, or a random sampling; and works well with data clustered in small patches, like those deriving from star (coordinate descent) sampling strategies.
 To work well with a latin hypercube sampling, it is necessary to include a pass of strategy b) before calling strategy a). Then strategy a) will charge itself of reducing the gradient errors created by the initial pass of strategy b).
 
 A configuration file should be prepared following the example in the "examples" folder in this distribution.
 If the configuration file is incomplete or missing, the program adopts its own defaults, exploiting the distance-weighted gradient-based strategy.
 
-The only variable that must mandatorily be specified in a configuration file is $sourcefile : the Unix path to the source file containining the dataseries.
+The only variable that must mandatorily be specified in a configuration file is $sourcefile : the Unix path to the source file containining the dataseries. If not specified, the program will look for "./sourcefile.csv".
 
 The source file has to be prepared by listing in each column the values (levels) of the parameters (factors, variables), putting in the last column the objective function values, in the rows in which they are present.
 
 The parameter number is given by the position of the column (i.e. column 4 host parameter 4).
 
-Here below an example is shown of multivatiate dataseries of 3 parameters assuming 3 levels each. The numbers preceding the objective function (which is in the last colum) are the indices of the multidimensional matrix (tensor).
+Here below an example is shown of multivatiate dataseries of 3 parameters assuming 3 levels each. The numbers preceding the objective function (which is in the last colum) are the indices of the multidimensional matrix (tensor). Note that the parameter listings (i.e. numbers describing levels) cannot be incomplete. Just the objective function entries can be.And the parameter listings must be integer numbers from 1 to n.
 
 
 1,1,1,1.234
@@ -2077,7 +2081,6 @@ Here below an example is shown of multivatiate dataseries of 3 parameters assumi
 3,3,3,3
 
 
-Note that the parameter listings cannot be incomplete. Just the objective function entries can be.
 The program converts this format into the one liked by Sim::OPTS, which is the following, in which the indices of the tensor are expressed more clearly:
 
 
@@ -2103,7 +2106,7 @@ The program converts this format into the one liked by Sim::OPTS, which is the f
 After some computations, Interlinear will output a new dataseries, with the missing values filled in.
 This dataseries can be used by OPT for the optimization of one or more blocks. This can be useful for saving computations in searches involving simulations, especially when the time required by each simulations is long, like it may happen with CFD simulations in building design.
 
-The number of computations required for the creation of a metamodel in OPT increases exponencially with the number of instances in the metamodel. To make the increase linear, a limit has to be set for the size of net of instances taken into account in the computations for gradients and for points. The variables in the configuration files controlling those limits are "$limit_checkgrades" and "$limit_checkpoints". By default they are both set to 10000. If a null value ("") is specified for them, no limit is assumed.
+The number of computations required for the creation of a metamodel in OPT increases exponencially with the number of instances in the metamodel. To make the increase linear, a limit has to be set for the size of net of instances taken into account in the computations for gradients and for points. The variables in the configuration files controlling those limits are "$limit_checkgrades" and "$limit_checkpoints". By default they are both set to "", which entails that no limit is assumed.
 
 
 =head2 EXPORT
@@ -2112,11 +2115,6 @@ The number of computations required for the creation of a metamodel in OPT incre
 interlinear, interstart.
 
 
-=head1 SEE ALSO
-
-
-An example of configuration file can be found in the "examples" folder in this distribution.
-
 
 =head1 AUTHOR
 
